package com.horcrux.svg;

import android.content.res.AssetManager;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.PathMeasure;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Typeface;
import android.os.Build;
import android.text.Layout;
import android.text.SpannableString;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.view.View;
import android.view.ViewParent;
import com.facebook.common.util.UriUtil;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.facebook.react.views.text.ReactFontManager;
import com.horcrux.svg.TextProperties;
import java.text.Bidi;
import java.util.ArrayList;
import javax.annotation.Nullable;

/* access modifiers changed from: package-private */
public class TSpanView extends TextView {
    private static final String FONTS = "fonts/";
    private static final String OTF = ".otf";
    private static final String TTF = ".ttf";
    static final String additionalLigatures = "'hlig', 'cala', ";
    static final String defaultFeatures = "'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', ";
    static final String disableDiscretionaryLigatures = "'liga' 0, 'clig' 0, 'dlig' 0, 'hlig' 0, 'cala' 0, ";
    static final String fontWeightTag = "'wght' ";
    private static final double radToDeg = 57.29577951308232d;
    static final String requiredFontFeatures = "'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk',";
    private static final double tau = 6.283185307179586d;
    private final AssetManager assets = this.mContext.getResources().getAssets();
    private final ArrayList<String> emoji = new ArrayList<>();
    private final ArrayList<Matrix> emojiTransforms = new ArrayList<>();
    private Path mCachedPath;
    @Nullable
    String mContent;
    private TextPathView textPath;

    public TSpanView(ReactContext reactContext) {
        super(reactContext);
    }

    @ReactProp(name = UriUtil.LOCAL_CONTENT_SCHEME)
    public void setContent(@Nullable String str) {
        this.mContent = str;
        invalidate();
    }

    @Override // com.horcrux.svg.VirtualView, com.horcrux.svg.TextView
    public void invalidate() {
        this.mCachedPath = null;
        super.invalidate();
    }

    /* access modifiers changed from: package-private */
    @Override // com.horcrux.svg.VirtualView, com.horcrux.svg.TextView
    public void clearCache() {
        this.mCachedPath = null;
        super.clearCache();
    }

    /* access modifiers changed from: package-private */
    @Override // com.horcrux.svg.VirtualView, com.horcrux.svg.RenderableView, com.horcrux.svg.TextView, com.horcrux.svg.GroupView
    public void draw(Canvas canvas, Paint paint, float f) {
        if (this.mContent == null) {
            clip(canvas, paint);
            drawGroup(canvas, paint, f);
        } else if (this.mInlineSize == null || this.mInlineSize.value == 0.0d) {
            int size = this.emoji.size();
            if (size > 0) {
                applyTextPropertiesToPaint(paint, getTextRootGlyphContext().getFont());
                for (int i = 0; i < size; i++) {
                    canvas.save();
                    canvas.concat(this.emojiTransforms.get(i));
                    canvas.drawText(this.emoji.get(i), 0.0f, 0.0f, paint);
                    canvas.restore();
                }
            }
            drawPath(canvas, paint, f);
        } else {
            if (setupFillPaint(paint, this.fillOpacity * f)) {
                drawWrappedText(canvas, paint);
            }
            if (setupStrokePaint(paint, f * this.strokeOpacity)) {
                drawWrappedText(canvas, paint);
            }
        }
    }

    private void drawWrappedText(Canvas canvas, Paint paint) {
        Layout.Alignment alignment;
        GlyphContext textRootGlyphContext = getTextRootGlyphContext();
        pushGlyphContext();
        FontData font = textRootGlyphContext.getFont();
        TextPaint textPaint = new TextPaint(paint);
        applyTextPropertiesToPaint(textPaint, font);
        applySpacingAndFeatures(textPaint, font);
        double fontSize = textRootGlyphContext.getFontSize();
        int i = AnonymousClass1.$SwitchMap$com$horcrux$svg$TextProperties$TextAnchor[font.textAnchor.ordinal()];
        if (i == 2) {
            alignment = Layout.Alignment.ALIGN_CENTER;
        } else if (i != 3) {
            alignment = Layout.Alignment.ALIGN_NORMAL;
        } else {
            alignment = Layout.Alignment.ALIGN_OPPOSITE;
        }
        StaticLayout staticLayout = getStaticLayout(textPaint, alignment, true, new SpannableString(this.mContent), (int) PropHelper.fromRelative(this.mInlineSize, (double) canvas.getWidth(), 0.0d, (double) this.mScale, fontSize));
        int lineAscent = staticLayout.getLineAscent(0);
        popGlyphContext();
        canvas.save();
        canvas.translate((float) textRootGlyphContext.nextX(0.0d), (float) (textRootGlyphContext.nextY() + ((double) lineAscent)));
        staticLayout.draw(canvas);
        canvas.restore();
    }

    private StaticLayout getStaticLayout(TextPaint textPaint, Layout.Alignment alignment, boolean z, SpannableString spannableString, int i) {
        if (Build.VERSION.SDK_INT < 23) {
            return new StaticLayout(spannableString, textPaint, i, alignment, 1.0f, 0.0f, z);
        }
        return StaticLayout.Builder.obtain(spannableString, 0, spannableString.length(), textPaint, i).setAlignment(alignment).setLineSpacing(0.0f, 1.0f).setIncludePad(z).setBreakStrategy(1).setHyphenationFrequency(1).build();
    }

    public static String visualToLogical(String str) {
        if (str == null || str.length() == 0) {
            return str;
        }
        Bidi bidi = new Bidi(str, -2);
        if (bidi.isLeftToRight()) {
            return str;
        }
        int runCount = bidi.getRunCount();
        byte[] bArr = new byte[runCount];
        Integer[] numArr = new Integer[runCount];
        for (int i = 0; i < runCount; i++) {
            bArr[i] = (byte) bidi.getRunLevel(i);
            numArr[i] = Integer.valueOf(i);
        }
        Bidi.reorderVisually(bArr, 0, numArr, 0, runCount);
        StringBuilder sb = new StringBuilder();
        for (int i2 = 0; i2 < runCount; i2++) {
            int intValue = numArr[i2].intValue();
            int runStart = bidi.getRunStart(intValue);
            int runLimit = bidi.getRunLimit(intValue);
            if ((bArr[intValue] & 1) != 0) {
                while (true) {
                    runLimit--;
                    if (runLimit < runStart) {
                        break;
                    }
                    sb.append(str.charAt(runLimit));
                }
            } else {
                sb.append((CharSequence) str, runStart, runLimit);
            }
        }
        return sb.toString();
    }

    /* access modifiers changed from: package-private */
    @Override // com.horcrux.svg.VirtualView, com.horcrux.svg.RenderableView, com.horcrux.svg.TextView, com.horcrux.svg.GroupView
    public Path getPath(Canvas canvas, Paint paint) {
        Path path = this.mCachedPath;
        if (path != null) {
            return path;
        }
        if (this.mContent == null) {
            Path groupPath = getGroupPath(canvas, paint);
            this.mCachedPath = groupPath;
            return groupPath;
        }
        setupTextPath();
        pushGlyphContext();
        this.mCachedPath = getLinePath(visualToLogical(this.mContent), paint, canvas);
        popGlyphContext();
        return this.mCachedPath;
    }

    /* access modifiers changed from: package-private */
    @Override // com.horcrux.svg.TextView
    public double getSubtreeTextChunksTotalAdvance(Paint paint) {
        if (!Double.isNaN(this.cachedAdvance)) {
            return this.cachedAdvance;
        }
        String str = this.mContent;
        double d = 0.0d;
        if (str == null) {
            for (int i = 0; i < getChildCount(); i++) {
                View childAt = getChildAt(i);
                if (childAt instanceof TextView) {
                    d += ((TextView) childAt).getSubtreeTextChunksTotalAdvance(paint);
                }
            }
            this.cachedAdvance = d;
            return d;
        } else if (str.length() == 0) {
            this.cachedAdvance = 0.0d;
            return 0.0d;
        } else {
            FontData font = getTextRootGlyphContext().getFont();
            applyTextPropertiesToPaint(paint, font);
            applySpacingAndFeatures(paint, font);
            this.cachedAdvance = (double) paint.measureText(str);
            return this.cachedAdvance;
        }
    }

    private void applySpacingAndFeatures(Paint paint, FontData fontData) {
        if (Build.VERSION.SDK_INT >= 21) {
            double d = fontData.letterSpacing;
            paint.setLetterSpacing((float) (d / (fontData.fontSize * ((double) this.mScale))));
            if (d == 0.0d && fontData.fontVariantLigatures == TextProperties.FontVariantLigatures.normal) {
                paint.setFontFeatureSettings("'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', 'hlig', 'cala', " + fontData.fontFeatureSettings);
            } else {
                paint.setFontFeatureSettings("'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', 'liga' 0, 'clig' 0, 'dlig' 0, 'hlig' 0, 'cala' 0, " + fontData.fontFeatureSettings);
            }
            if (Build.VERSION.SDK_INT >= 26) {
                paint.setFontVariationSettings(fontWeightTag + fontData.absoluteFontWeight + fontData.fontVariationSettings);
            }
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Removed duplicated region for block: B:106:0x02a5 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:118:0x02f4  */
    /* JADX WARNING: Removed duplicated region for block: B:83:0x022f  */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x0231  */
    /* JADX WARNING: Removed duplicated region for block: B:87:0x023c  */
    /* JADX WARNING: Removed duplicated region for block: B:90:0x0247  */
    /* JADX WARNING: Removed duplicated region for block: B:95:0x025a  */
    /* JADX WARNING: Removed duplicated region for block: B:96:0x026e A[ADDED_TO_REGION] */
    private Path getLinePath(String str, Paint paint, Canvas canvas) {
        boolean z;
        PathMeasure pathMeasure;
        double d;
        GlyphPathBag glyphPathBag;
        float[] fArr;
        boolean[] zArr;
        GlyphContext glyphContext;
        boolean z2;
        int i;
        double d2;
        double d3;
        double d4;
        int i2;
        int i3;
        boolean z3;
        String str2;
        boolean z4;
        int i4;
        double d5;
        double d6;
        double d7;
        double d8;
        PathMeasure pathMeasure2;
        int i5;
        double d9;
        Matrix matrix;
        float[] fArr2;
        int i6;
        Paint paint2;
        GlyphContext glyphContext2;
        TSpanView tSpanView;
        int i7;
        float[] fArr3;
        GlyphPathBag glyphPathBag2;
        Path path;
        double d10;
        GlyphContext glyphContext3;
        char c;
        PathMeasure pathMeasure3;
        double d11;
        String str3;
        Path path2;
        int i8;
        double d12;
        int i9;
        char c2;
        double d13;
        TSpanView tSpanView2 = this;
        Paint paint3 = paint;
        int length = str.length();
        Path path3 = new Path();
        tSpanView2.emoji.clear();
        tSpanView2.emojiTransforms.clear();
        if (length == 0) {
            return path3;
        }
        boolean z5 = tSpanView2.textPath != null;
        if (z5) {
            PathMeasure pathMeasure4 = new PathMeasure(tSpanView2.textPath.getTextPath(canvas, paint3), false);
            double length2 = (double) pathMeasure4.getLength();
            boolean isClosed = pathMeasure4.isClosed();
            if (length2 == 0.0d) {
                return path3;
            }
            pathMeasure = pathMeasure4;
            d = length2;
            z = isClosed;
        } else {
            pathMeasure = null;
            d = 0.0d;
            z = false;
        }
        GlyphContext textRootGlyphContext = getTextRootGlyphContext();
        FontData font = textRootGlyphContext.getFont();
        tSpanView2.applyTextPropertiesToPaint(paint3, font);
        GlyphPathBag glyphPathBag3 = new GlyphPathBag(paint3);
        boolean[] zArr2 = new boolean[length];
        char[] charArray = str.toCharArray();
        Path path4 = path3;
        double d14 = font.kerning;
        double d15 = font.wordSpacing;
        double d16 = font.letterSpacing;
        boolean z6 = !font.manualKerning;
        boolean z7 = d16 == 0.0d && font.fontVariantLigatures == TextProperties.FontVariantLigatures.normal;
        if (Build.VERSION.SDK_INT >= 21) {
            if (z7) {
                paint3.setFontFeatureSettings("'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', 'hlig', 'cala', " + font.fontFeatureSettings);
            } else {
                paint3.setFontFeatureSettings("'rlig', 'liga', 'clig', 'calt', 'locl', 'ccmp', 'mark', 'mkmk','kern', 'liga' 0, 'clig' 0, 'dlig' 0, 'hlig' 0, 'cala' 0, " + font.fontFeatureSettings);
            }
            if (Build.VERSION.SDK_INT >= 26) {
                paint3.setFontVariationSettings(fontWeightTag + font.absoluteFontWeight + font.fontVariationSettings);
            }
        }
        ReadableMap readableMap = font.fontData;
        float[] fArr4 = new float[length];
        paint3.getTextWidths(str, fArr4);
        TextProperties.TextAnchor textAnchor = font.textAnchor;
        PathMeasure pathMeasure5 = pathMeasure;
        double d17 = d16;
        double subtreeTextChunksTotalAdvance = getTextAnchorRoot().getSubtreeTextChunksTotalAdvance(paint3);
        double textAnchorOffset = tSpanView2.getTextAnchorOffset(textAnchor, subtreeTextChunksTotalAdvance);
        double fontSize = textRootGlyphContext.getFontSize();
        if (z5) {
            boolean z8 = tSpanView2.textPath.getMidLine() == TextProperties.TextPathMidLine.sharp;
            int i10 = tSpanView2.textPath.getSide() == TextProperties.TextPathSide.right ? -1 : 1;
            zArr = zArr2;
            fArr = fArr4;
            glyphContext = textRootGlyphContext;
            glyphPathBag = glyphPathBag3;
            double absoluteStartOffset = getAbsoluteStartOffset(tSpanView2.textPath.getStartOffset(), d, fontSize);
            textAnchorOffset += absoluteStartOffset;
            if (z) {
                d3 = absoluteStartOffset + (textAnchor == TextProperties.TextAnchor.middle ? -(d / 2.0d) : 0.0d);
                d2 = d3 + d;
            } else {
                d2 = d;
                d3 = 0.0d;
            }
            i = i10;
            z2 = z8;
        } else {
            zArr = zArr2;
            fArr = fArr4;
            glyphContext = textRootGlyphContext;
            glyphPathBag = glyphPathBag3;
            d2 = d;
            d3 = 0.0d;
            i = 1;
            z2 = false;
        }
        double d18 = 1.0d;
        double d19 = d;
        if (tSpanView2.mTextLength != null) {
            d4 = d3;
            double fromRelative = PropHelper.fromRelative(tSpanView2.mTextLength, (double) canvas.getWidth(), 0.0d, (double) tSpanView2.mScale, fontSize);
            if (fromRelative < 0.0d) {
                throw new IllegalArgumentException("Negative textLength value");
            } else if (AnonymousClass1.$SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust[tSpanView2.mLengthAdjust.ordinal()] != 2) {
                d17 += (fromRelative - subtreeTextChunksTotalAdvance) / ((double) (length - 1));
            } else {
                d18 = fromRelative / subtreeTextChunksTotalAdvance;
            }
        } else {
            d4 = d3;
        }
        double d20 = (double) i;
        Paint.FontMetrics fontMetrics = paint.getFontMetrics();
        double d21 = (double) fontMetrics.descent;
        int i11 = i;
        double d22 = d18 * d20;
        double d23 = ((double) fontMetrics.leading) + d21;
        double d24 = (double) ((-fontMetrics.ascent) + fontMetrics.leading);
        double d25 = (double) (-fontMetrics.top);
        double d26 = d25 + d23;
        String baselineShift = getBaselineShift();
        TextProperties.AlignmentBaseline alignmentBaseline = getAlignmentBaseline();
        if (alignmentBaseline != null) {
            switch (alignmentBaseline) {
                case textBottom:
                case afterEdge:
                case textAfterEdge:
                case ideographic:
                    d23 = -d21;
                    break;
                case middle:
                    Rect rect = new Rect();
                    paint3.getTextBounds("x", 0, 1, rect);
                    d23 = ((double) rect.height()) / 2.0d;
                    break;
                case central:
                    d23 = (d24 - d21) / 2.0d;
                    break;
                case mathematical:
                    d13 = 0.5d;
                    d23 = d24 * d13;
                    break;
                case hanging:
                    d13 = 0.8d;
                    d23 = d24 * d13;
                    break;
                case textTop:
                case beforeEdge:
                case textBeforeEdge:
                    d23 = d24;
                    break;
                case center:
                    d23 = d26 / 2.0d;
                    break;
                case top:
                    d23 = d25;
                    break;
            }
            if (!(baselineShift == null || baselineShift.isEmpty() || (i9 = AnonymousClass1.$SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[alignmentBaseline.ordinal()]) == 14 || i9 == 16)) {
                baselineShift.hashCode();
                switch (baselineShift.hashCode()) {
                    case -1720785339:
                        if (baselineShift.equals("baseline")) {
                            c2 = 0;
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 114240:
                        if (baselineShift.equals("sub")) {
                            c2 = 1;
                            break;
                        }
                        c2 = 65535;
                        break;
                    case 109801339:
                        if (baselineShift.equals("super")) {
                            c2 = 2;
                            break;
                        }
                        c2 = 65535;
                        break;
                    default:
                        c2 = 65535;
                        break;
                }
                switch (c2) {
                    case 0:
                        break;
                    case 1:
                        if (readableMap != null && readableMap.hasKey("tables") && readableMap.hasKey("unitsPerEm")) {
                            int i12 = readableMap.getInt("unitsPerEm");
                            ReadableMap map = readableMap.getMap("tables");
                            if (map.hasKey("os2")) {
                                ReadableMap map2 = map.getMap("os2");
                                if (map2.hasKey("ySubscriptYOffset")) {
                                    d23 += ((((double) tSpanView2.mScale) * fontSize) * map2.getDouble("ySubscriptYOffset")) / ((double) i12);
                                    break;
                                }
                            }
                        }
                        break;
                    case 2:
                        if (readableMap != null && readableMap.hasKey("tables") && readableMap.hasKey("unitsPerEm")) {
                            int i13 = readableMap.getInt("unitsPerEm");
                            ReadableMap map3 = readableMap.getMap("tables");
                            if (map3.hasKey("os2")) {
                                ReadableMap map4 = map3.getMap("os2");
                                if (map4.hasKey("ySuperscriptYOffset")) {
                                    d23 -= ((((double) tSpanView2.mScale) * fontSize) * map4.getDouble("ySuperscriptYOffset")) / ((double) i13);
                                    break;
                                }
                            }
                        }
                        break;
                    default:
                        d23 -= PropHelper.fromRelative(baselineShift, ((double) tSpanView2.mScale) * fontSize, (double) tSpanView2.mScale, fontSize);
                        break;
                }
            }
            double d27 = d23;
            Matrix matrix2 = new Matrix();
            Matrix matrix3 = new Matrix();
            Matrix matrix4 = new Matrix();
            float[] fArr5 = new float[9];
            float[] fArr6 = new float[9];
            i2 = 0;
            while (i2 < length) {
                char c3 = charArray[i2];
                String valueOf = String.valueOf(c3);
                boolean z9 = zArr[i2];
                if (z9) {
                    str2 = "";
                    i3 = length;
                    z3 = false;
                } else {
                    String str4 = valueOf;
                    int i14 = i2;
                    z3 = false;
                    while (true) {
                        int i15 = i14 + 1;
                        if (i15 >= length || fArr[i15] > 0.0f) {
                            i3 = length;
                            str2 = str4;
                        } else {
                            str4 = str4 + charArray[i15];
                            zArr[i15] = true;
                            i14 = i15;
                            length = length;
                            z3 = true;
                        }
                    }
                    i3 = length;
                    str2 = str4;
                }
                double measureText = ((double) paint3.measureText(str2)) * d18;
                if (z6) {
                    z4 = z3;
                    i4 = i2;
                    d14 = (((double) fArr[i2]) * d18) - measureText;
                } else {
                    z4 = z3;
                    i4 = i2;
                }
                boolean z10 = c3 == ' ';
                double d28 = (z10 ? d15 : 0.0d) + d17 + measureText;
                if (z9) {
                    d5 = d27;
                    d6 = 0.0d;
                } else {
                    d5 = d27;
                    d6 = d14 + d28;
                }
                double nextX = glyphContext.nextX(d6);
                float[] fArr7 = fArr5;
                double nextY = glyphContext.nextY();
                double nextDeltaX = glyphContext.nextDeltaX();
                double nextDeltaY = glyphContext.nextDeltaY();
                double nextRotation = glyphContext.nextRotation();
                if (!z9 && !z10) {
                    double d29 = measureText * d20;
                    double d30 = (textAnchorOffset + ((nextX + nextDeltaX) * d20)) - (d28 * d20);
                    if (z5) {
                        double d31 = d30 + d29;
                        double d32 = d29 / 2.0d;
                        c = c3;
                        double d33 = d30 + d32;
                        if (d33 <= d2 && d33 >= d4) {
                            glyphContext3 = glyphContext;
                            if (z2) {
                                pathMeasure5.getMatrix((float) d33, matrix3, 3);
                                pathMeasure3 = pathMeasure5;
                                d10 = nextRotation;
                            } else {
                                pathMeasure3 = pathMeasure5;
                                if (d30 < 0.0d) {
                                    d10 = nextRotation;
                                    pathMeasure3.getMatrix(0.0f, matrix2, 3);
                                    matrix2.preTranslate((float) d30, 0.0f);
                                    i8 = 1;
                                } else {
                                    d10 = nextRotation;
                                    i8 = 1;
                                    pathMeasure3.getMatrix((float) d30, matrix2, 1);
                                }
                                pathMeasure3.getMatrix((float) d33, matrix3, i8);
                                if (d31 > d19) {
                                    d12 = d19;
                                    pathMeasure3.getMatrix((float) d12, matrix4, 3);
                                    matrix4.preTranslate((float) (d31 - d12), 0.0f);
                                } else {
                                    d12 = d19;
                                    pathMeasure3.getMatrix((float) d31, matrix4, i8);
                                }
                                matrix2.getValues(fArr7);
                                matrix4.getValues(fArr6);
                                d19 = d12;
                                double d34 = (double) fArr7[5];
                                fArr7 = fArr7;
                                matrix3.preRotate((float) (Math.atan2(((double) fArr6[5]) - d34, ((double) fArr6[2]) - ((double) fArr7[2])) * radToDeg * d20));
                            }
                            matrix3.preTranslate((float) (-d32), (float) (nextDeltaY + d5));
                            d11 = d22;
                            i7 = i11;
                            matrix3.preScale((float) d11, (float) i7);
                            matrix3.postTranslate(0.0f, (float) nextY);
                        }
                    } else {
                        c = c3;
                        d10 = nextRotation;
                        glyphContext3 = glyphContext;
                        pathMeasure3 = pathMeasure5;
                        i7 = i11;
                        d11 = d22;
                        matrix3.setTranslate((float) d30, (float) (nextY + nextDeltaY + d5));
                    }
                    matrix3.preRotate((float) d10);
                    if (z4) {
                        path2 = new Path();
                        pathMeasure2 = pathMeasure3;
                        i5 = i4;
                        fArr2 = fArr6;
                        d8 = d11;
                        d9 = d15;
                        fArr3 = fArr7;
                        matrix = matrix4;
                        d7 = d20;
                        path = path4;
                        i6 = i3;
                        paint.getTextPath(str2, 0, str2.length(), 0.0f, 0.0f, path2);
                        str3 = str2;
                        glyphPathBag2 = glyphPathBag;
                    } else {
                        d9 = d15;
                        i6 = i3;
                        str3 = str2;
                        i5 = i4;
                        fArr3 = fArr7;
                        d8 = d11;
                        pathMeasure2 = pathMeasure3;
                        fArr2 = fArr6;
                        d7 = d20;
                        path = path4;
                        glyphPathBag2 = glyphPathBag;
                        matrix = matrix4;
                        path2 = glyphPathBag2.getOrCreateAndCache(c, str3);
                    }
                    RectF rectF = new RectF();
                    path2.computeBounds(rectF, true);
                    if (rectF.width() == 0.0f) {
                        canvas.save();
                        glyphContext2 = glyphContext3;
                        canvas.concat(matrix3);
                        tSpanView = this;
                        tSpanView.emoji.add(str3);
                        tSpanView.emojiTransforms.add(new Matrix(matrix3));
                        paint2 = paint;
                        canvas.drawText(str3, 0.0f, 0.0f, paint2);
                        canvas.restore();
                    } else {
                        tSpanView = this;
                        paint2 = paint;
                        glyphContext2 = glyphContext3;
                        path2.transform(matrix3);
                        path.addPath(path2);
                    }
                    int i16 = i5 + 1;
                    glyphPathBag = glyphPathBag2;
                    i11 = i7;
                    tSpanView2 = tSpanView;
                    length = i6;
                    matrix4 = matrix;
                    d15 = d9;
                    pathMeasure5 = pathMeasure2;
                    d22 = d8;
                    path4 = path;
                    i2 = i16;
                    paint3 = paint2;
                    d20 = d7;
                    fArr5 = fArr3;
                    d27 = d5;
                    glyphContext = glyphContext2;
                    fArr6 = fArr2;
                }
                tSpanView = this;
                paint2 = paint;
                glyphContext2 = glyphContext;
                d9 = d15;
                pathMeasure2 = pathMeasure5;
                i6 = i3;
                i5 = i4;
                fArr3 = fArr7;
                fArr2 = fArr6;
                i7 = i11;
                d8 = d22;
                d7 = d20;
                path = path4;
                glyphPathBag2 = glyphPathBag;
                matrix = matrix4;
                int i162 = i5 + 1;
                glyphPathBag = glyphPathBag2;
                i11 = i7;
                tSpanView2 = tSpanView;
                length = i6;
                matrix4 = matrix;
                d15 = d9;
                pathMeasure5 = pathMeasure2;
                d22 = d8;
                path4 = path;
                i2 = i162;
                paint3 = paint2;
                d20 = d7;
                fArr5 = fArr3;
                d27 = d5;
                glyphContext = glyphContext2;
                fArr6 = fArr2;
            }
            return path4;
        }
        d23 = 0.0d;
        baselineShift.hashCode();
        switch (baselineShift.hashCode()) {
            case -1720785339:
                break;
            case 114240:
                break;
            case 109801339:
                break;
        }
        switch (c2) {
        }
        double d272 = d23;
        Matrix matrix22 = new Matrix();
        Matrix matrix32 = new Matrix();
        Matrix matrix42 = new Matrix();
        float[] fArr52 = new float[9];
        float[] fArr62 = new float[9];
        i2 = 0;
        while (i2 < length) {
        }
        return path4;
    }

    /* access modifiers changed from: package-private */
    /* renamed from: com.horcrux.svg.TSpanView$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor;
        static final /* synthetic */ int[] $SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust;

        /* JADX WARNING: Can't wrap try/catch for region: R(42:0|(2:1|2)|3|(2:5|6)|7|9|10|11|12|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|(2:35|36)|37|39|40|(2:41|42)|43|45|46|47|48|(3:49|50|52)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(45:0|(2:1|2)|3|(2:5|6)|7|9|10|11|12|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|39|40|(2:41|42)|43|45|46|47|48|49|50|52) */
        /* JADX WARNING: Can't wrap try/catch for region: R(46:0|(2:1|2)|3|5|6|7|9|10|11|12|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|39|40|(2:41|42)|43|45|46|47|48|49|50|52) */
        /* JADX WARNING: Can't wrap try/catch for region: R(47:0|(2:1|2)|3|5|6|7|9|10|11|12|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|39|40|41|42|43|45|46|47|48|49|50|52) */
        /* JADX WARNING: Can't wrap try/catch for region: R(48:0|1|2|3|5|6|7|9|10|11|12|13|14|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|39|40|41|42|43|45|46|47|48|49|50|52) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x0028 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:13:0x0033 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:15:0x003e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:17:0x0049 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x0054 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:21:0x0060 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:23:0x006c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:25:0x0078 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:27:0x0084 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:29:0x0090 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:31:0x009c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:33:0x00a8 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:35:0x00b4 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:41:0x00d1 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:47:0x00ec */
        /* JADX WARNING: Missing exception handler attribute for start block: B:49:0x00f6 */
        static {
            int[] iArr = new int[TextProperties.AlignmentBaseline.values().length];
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline = iArr;
            try {
                iArr[TextProperties.AlignmentBaseline.baseline.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textBottom.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.afterEdge.ordinal()] = 3;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textAfterEdge.ordinal()] = 4;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.alphabetic.ordinal()] = 5;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.ideographic.ordinal()] = 6;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.middle.ordinal()] = 7;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.central.ordinal()] = 8;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.mathematical.ordinal()] = 9;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.hanging.ordinal()] = 10;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textTop.ordinal()] = 11;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.beforeEdge.ordinal()] = 12;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.textBeforeEdge.ordinal()] = 13;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.bottom.ordinal()] = 14;
            $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.center.ordinal()] = 15;
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$AlignmentBaseline[TextProperties.AlignmentBaseline.top.ordinal()] = 16;
            } catch (NoSuchFieldError unused3) {
            }
            int[] iArr2 = new int[TextProperties.TextLengthAdjust.values().length];
            $SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust = iArr2;
            iArr2[TextProperties.TextLengthAdjust.spacing.ordinal()] = 1;
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$TextLengthAdjust[TextProperties.TextLengthAdjust.spacingAndGlyphs.ordinal()] = 2;
            } catch (NoSuchFieldError unused4) {
            }
            int[] iArr3 = new int[TextProperties.TextAnchor.values().length];
            $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor = iArr3;
            iArr3[TextProperties.TextAnchor.start.ordinal()] = 1;
            $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor[TextProperties.TextAnchor.middle.ordinal()] = 2;
            try {
                $SwitchMap$com$horcrux$svg$TextProperties$TextAnchor[TextProperties.TextAnchor.end.ordinal()] = 3;
            } catch (NoSuchFieldError unused5) {
            }
        }
    }

    private double getAbsoluteStartOffset(SVGLength sVGLength, double d, double d2) {
        return PropHelper.fromRelative(sVGLength, d, 0.0d, (double) this.mScale, d2);
    }

    private double getTextAnchorOffset(TextProperties.TextAnchor textAnchor, double d) {
        int i = AnonymousClass1.$SwitchMap$com$horcrux$svg$TextProperties$TextAnchor[textAnchor.ordinal()];
        if (i == 2) {
            return (-d) / 2.0d;
        }
        if (i != 3) {
            return 0.0d;
        }
        return -d;
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(4:26|27|28|29) */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:28:0x00c5 */
    private void applyTextPropertiesToPaint(Paint paint, FontData fontData) {
        int i = 0;
        boolean z = fontData.fontWeight == TextProperties.FontWeight.Bold || fontData.absoluteFontWeight >= 550;
        boolean z2 = fontData.fontStyle == TextProperties.FontStyle.italic;
        if (z && z2) {
            i = 3;
        } else if (z) {
            i = 1;
        } else if (z2) {
            i = 2;
        }
        Typeface typeface = null;
        int i2 = fontData.absoluteFontWeight;
        String str = fontData.fontFamily;
        if (str != null && str.length() > 0) {
            String str2 = FONTS + str + OTF;
            String str3 = FONTS + str + TTF;
            if (Build.VERSION.SDK_INT >= 26) {
                Typeface.Builder builder = new Typeface.Builder(this.assets, str2);
                builder.setFontVariationSettings(fontWeightTag + i2 + fontData.fontVariationSettings);
                builder.setWeight(i2);
                builder.setItalic(z2);
                typeface = builder.build();
                if (typeface == null) {
                    Typeface.Builder builder2 = new Typeface.Builder(this.assets, str3);
                    builder2.setFontVariationSettings(fontWeightTag + i2 + fontData.fontVariationSettings);
                    builder2.setWeight(i2);
                    builder2.setItalic(z2);
                    typeface = builder2.build();
                }
            } else {
                typeface = Typeface.create(Typeface.createFromAsset(this.assets, str2), i);
                typeface = Typeface.create(Typeface.createFromAsset(this.assets, str3), i);
            }
        }
        if (typeface == null) {
            try {
                typeface = ReactFontManager.getInstance().getTypeface(str, i, this.assets);
            } catch (Exception unused) {
            }
        }
        if (Build.VERSION.SDK_INT >= 28) {
            typeface = Typeface.create(typeface, i2, z2);
        }
        paint.setLinearText(true);
        paint.setSubpixelText(true);
        paint.setTypeface(typeface);
        paint.setTextSize((float) (fontData.fontSize * ((double) this.mScale)));
        if (Build.VERSION.SDK_INT >= 21) {
            paint.setLetterSpacing(0.0f);
        }
    }

    private void setupTextPath() {
        for (ViewParent parent = getParent(); parent != null; parent = parent.getParent()) {
            if (parent.getClass() == TextPathView.class) {
                this.textPath = (TextPathView) parent;
                return;
            } else if (!(parent instanceof TextView)) {
                return;
            }
        }
    }

    /* access modifiers changed from: package-private */
    @Override // com.horcrux.svg.VirtualView, com.horcrux.svg.RenderableView, com.horcrux.svg.GroupView
    public int hitTest(float[] fArr) {
        if (this.mContent == null) {
            return super.hitTest(fArr);
        }
        if (this.mPath != null && this.mInvertible && this.mTransformInvertible) {
            float[] fArr2 = new float[2];
            this.mInvMatrix.mapPoints(fArr2, fArr);
            this.mInvTransform.mapPoints(fArr2);
            int round = Math.round(fArr2[0]);
            int round2 = Math.round(fArr2[1]);
            initBounds();
            if ((this.mRegion != null && this.mRegion.contains(round, round2)) || (this.mStrokeRegion != null && this.mStrokeRegion.contains(round, round2))) {
                if (getClipPath() == null || this.mClipRegion.contains(round, round2)) {
                    return getId();
                }
                return -1;
            }
        }
        return -1;
    }
}
