package com.reactnativecommunity.asyncstorage;

import android.content.Context;
import android.os.Build;
import android.util.Log;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.channels.FileChannel;
import java.nio.file.Files;
import java.nio.file.LinkOption;
import java.nio.file.attribute.BasicFileAttributes;
import java.util.ArrayList;
import java.util.Iterator;

public class AsyncStorageExpoMigration {
    static final String LOG_TAG = "AsyncStorageExpoMigration";

    public static void migrate(Context context) {
        if (!isAsyncStorageDatabaseCreated(context)) {
            ArrayList<File> expoDatabases = getExpoDatabases(context);
            File lastModifiedFile = getLastModifiedFile(expoDatabases);
            if (lastModifiedFile == null) {
                Log.v(LOG_TAG, "No scoped database found");
                return;
            }
            try {
                ReactDatabaseSupplier.getInstance(context).get();
                copyFile(new FileInputStream(lastModifiedFile), new FileOutputStream(context.getDatabasePath("RKStorage")));
                Log.v(LOG_TAG, "Migrated most recently modified database " + lastModifiedFile.getName() + " to RKStorage");
                try {
                    Iterator<File> it = expoDatabases.iterator();
                    while (it.hasNext()) {
                        File next = it.next();
                        if (next.delete()) {
                            Log.v(LOG_TAG, "Deleted scoped database " + next.getName());
                        } else {
                            Log.v(LOG_TAG, "Failed to delete scoped database " + next.getName());
                        }
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
                Log.v(LOG_TAG, "Completed the scoped AsyncStorage migration");
            } catch (Exception e2) {
                Log.v(LOG_TAG, "Failed to migrate scoped database " + lastModifiedFile.getName());
                e2.printStackTrace();
            }
        }
    }

    private static boolean isAsyncStorageDatabaseCreated(Context context) {
        return context.getDatabasePath("RKStorage").exists();
    }

    private static ArrayList<File> getExpoDatabases(Context context) {
        ArrayList<File> arrayList = new ArrayList<>();
        try {
            File[] listFiles = context.getDatabasePath("noop").getParentFile().listFiles();
            if (listFiles != null) {
                for (File file : listFiles) {
                    if (file.getName().startsWith("RKStorage-scoped-experience-") && !file.getName().endsWith("-journal")) {
                        arrayList.add(file);
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return arrayList;
    }

    private static File getLastModifiedFile(ArrayList<File> arrayList) {
        File file = null;
        if (arrayList.size() == 0) {
            return null;
        }
        long j = -1;
        Iterator<File> it = arrayList.iterator();
        while (it.hasNext()) {
            File next = it.next();
            long lastModifiedTimeInMillis = getLastModifiedTimeInMillis(next);
            if (lastModifiedTimeInMillis > j) {
                file = next;
                j = lastModifiedTimeInMillis;
            }
        }
        if (file != null) {
            return file;
        }
        return arrayList.get(0);
    }

    private static long getLastModifiedTimeInMillis(File file) {
        try {
            if (Build.VERSION.SDK_INT >= 26) {
                return getLastModifiedTimeFromBasicFileAttrs(file);
            }
            return file.lastModified();
        } catch (Exception e) {
            e.printStackTrace();
            return -1;
        }
    }

    private static long getLastModifiedTimeFromBasicFileAttrs(File file) {
        try {
            return Files.readAttributes(file.toPath(), BasicFileAttributes.class, new LinkOption[0]).creationTime().toMillis();
        } catch (Exception unused) {
            return -1;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:19:0x0030 A[SYNTHETIC, Splitter:B:19:0x0030] */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x003d  */
    private static void copyFile(FileInputStream fileInputStream, FileOutputStream fileOutputStream) throws IOException {
        Throwable th;
        FileChannel fileChannel;
        FileChannel fileChannel2 = null;
        try {
            FileChannel channel = fileInputStream.getChannel();
            try {
                fileChannel2 = fileOutputStream.getChannel();
                channel.transferTo(0, channel.size(), fileChannel2);
                if (channel != null) {
                    try {
                        channel.close();
                    } catch (Throwable th2) {
                        if (fileChannel2 != null) {
                            fileChannel2.close();
                        }
                        throw th2;
                    }
                }
                if (fileChannel2 != null) {
                    fileChannel2.close();
                }
            } catch (Throwable th3) {
                th = th3;
                fileChannel2 = channel;
                fileChannel = fileChannel2;
                if (fileChannel2 != null) {
                    try {
                        fileChannel2.close();
                    } catch (Throwable th4) {
                        if (fileChannel != null) {
                            fileChannel.close();
                        }
                        throw th4;
                    }
                }
                if (fileChannel != null) {
                    fileChannel.close();
                }
                throw th;
            }
        } catch (Throwable th5) {
            th = th5;
            fileChannel = null;
            if (fileChannel2 != null) {
            }
            if (fileChannel != null) {
            }
            throw th;
        }
    }
}
