package expo.modules.barcodescanner.scanners;

import android.content.Context;
import android.graphics.Bitmap;
import com.facebook.common.util.UriUtil;
import com.facebook.react.uimanager.ViewProps;
import com.google.zxing.BarcodeFormat;
import com.google.zxing.BinaryBitmap;
import com.google.zxing.DecodeHintType;
import com.google.zxing.LuminanceSource;
import com.google.zxing.MultiFormatReader;
import com.google.zxing.NotFoundException;
import com.google.zxing.PlanarYUVLuminanceSource;
import com.google.zxing.RGBLuminanceSource;
import com.google.zxing.Result;
import com.google.zxing.common.HybridBinarizer;
import expo.modules.interfaces.barcodescanner.BarCodeScannerResult;
import expo.modules.interfaces.barcodescanner.BarCodeScannerSettings;
import java.util.ArrayList;
import java.util.EnumMap;
import java.util.EnumSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import kotlin.Metadata;
import kotlin.TuplesKt;
import kotlin.collections.CollectionsKt;
import kotlin.collections.MapsKt;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;

@Metadata(d1 = {"\u0000V\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0010\u000b\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u0012\n\u0000\n\u0002\u0010\b\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\b\u0004\n\u0002\u0010 \n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0002\u0018\u0000 \u001e2\u00020\u0001:\u0001\u001eB\r\u0012\u0006\u0010\u0002\u001a\u00020\u0003¢\u0006\u0002\u0010\u0004J \u0010\n\u001a\u00020\u000b2\u0006\u0010\f\u001a\u00020\r2\u0006\u0010\u000e\u001a\u00020\u000f2\u0006\u0010\u0010\u001a\u00020\u000fH\u0002J\u0012\u0010\u0011\u001a\u0004\u0018\u00010\u00122\u0006\u0010\u0013\u001a\u00020\u000bH\u0002J*\u0010\u0011\u001a\u0004\u0018\u00010\u00122\u0006\u0010\u0014\u001a\u00020\r2\u0006\u0010\u000e\u001a\u00020\u000f2\u0006\u0010\u0010\u001a\u00020\u000f2\u0006\u0010\u0015\u001a\u00020\u000fH\u0016J\u0016\u0010\u0016\u001a\b\u0012\u0004\u0012\u00020\u00120\u00172\u0006\u0010\u0018\u001a\u00020\u0019H\u0016J\u0010\u0010\u001a\u001a\u00020\u001b2\u0006\u0010\u001c\u001a\u00020\u001dH\u0016R\u0014\u0010\u0005\u001a\u00020\u0006XD¢\u0006\b\n\u0000\u001a\u0004\b\u0005\u0010\u0007R\u000e\u0010\b\u001a\u00020\tX\u0004¢\u0006\u0002\n\u0000¨\u0006\u001f"}, d2 = {"Lexpo/modules/barcodescanner/scanners/ZxingBarCodeScanner;", "Lexpo/modules/barcodescanner/scanners/ExpoBarCodeScanner;", "context", "Landroid/content/Context;", "(Landroid/content/Context;)V", "isAvailable", "", "()Z", "mMultiFormatReader", "Lcom/google/zxing/MultiFormatReader;", "generateSourceFromImageData", "Lcom/google/zxing/LuminanceSource;", "imageData", "", "width", "", "height", "scan", "Lexpo/modules/interfaces/barcodescanner/BarCodeScannerResult;", "source", UriUtil.DATA_SCHEME, ViewProps.ROTATION, "scanMultiple", "", "bitmap", "Landroid/graphics/Bitmap;", "setSettings", "", "settings", "Lexpo/modules/interfaces/barcodescanner/BarCodeScannerSettings;", "Companion", "expo-barcode-scanner_release"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* compiled from: ZxingBarCodeScanner.kt */
public final class ZxingBarCodeScanner extends ExpoBarCodeScanner {
    public static final Companion Companion = new Companion(null);
    private static final Map<BarcodeFormat, Integer> GMV_FROM_ZXING = MapsKt.mapOf(TuplesKt.to(BarcodeFormat.AZTEC, 4096), TuplesKt.to(BarcodeFormat.EAN_13, 32), TuplesKt.to(BarcodeFormat.EAN_8, 64), TuplesKt.to(BarcodeFormat.QR_CODE, 256), TuplesKt.to(BarcodeFormat.PDF_417, 2048), TuplesKt.to(BarcodeFormat.UPC_E, 1024), TuplesKt.to(BarcodeFormat.DATA_MATRIX, 16), TuplesKt.to(BarcodeFormat.CODE_39, 2), TuplesKt.to(BarcodeFormat.CODE_93, 4), TuplesKt.to(BarcodeFormat.ITF, 128), TuplesKt.to(BarcodeFormat.CODABAR, 8), TuplesKt.to(BarcodeFormat.CODE_128, 1), TuplesKt.to(BarcodeFormat.UPC_A, 512));
    private static final Map<Integer, String> VALID_BARCODE_TYPES = MapsKt.mapOf(TuplesKt.to(4096, BarcodeFormat.AZTEC.toString()), TuplesKt.to(32, BarcodeFormat.EAN_13.toString()), TuplesKt.to(64, BarcodeFormat.EAN_8.toString()), TuplesKt.to(256, BarcodeFormat.QR_CODE.toString()), TuplesKt.to(2048, BarcodeFormat.PDF_417.toString()), TuplesKt.to(1024, BarcodeFormat.UPC_E.toString()), TuplesKt.to(16, BarcodeFormat.DATA_MATRIX.toString()), TuplesKt.to(2, BarcodeFormat.CODE_39.toString()), TuplesKt.to(4, BarcodeFormat.CODE_93.toString()), TuplesKt.to(128, BarcodeFormat.ITF.toString()), TuplesKt.to(8, BarcodeFormat.CODABAR.toString()), TuplesKt.to(1, BarcodeFormat.CODE_128.toString()), TuplesKt.to(512, BarcodeFormat.UPC_A.toString()));
    private final boolean isAvailable = true;
    private final MultiFormatReader mMultiFormatReader = new MultiFormatReader();

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public ZxingBarCodeScanner(Context context) {
        super(context);
        Intrinsics.checkNotNullParameter(context, "context");
    }

    @Override // expo.modules.interfaces.barcodescanner.BarCodeScannerInterface
    public List<BarCodeScannerResult> scanMultiple(Bitmap bitmap) {
        List<BarCodeScannerResult> list;
        Intrinsics.checkNotNullParameter(bitmap, "bitmap");
        int[] iArr = new int[(bitmap.getWidth() * bitmap.getHeight())];
        bitmap.getPixels(iArr, 0, bitmap.getWidth(), 0, 0, bitmap.getWidth(), bitmap.getHeight());
        BarCodeScannerResult scan = scan(new RGBLuminanceSource(bitmap.getWidth(), bitmap.getHeight(), iArr));
        if (scan == null) {
            list = null;
        } else {
            list = CollectionsKt.listOf(scan);
        }
        return list == null ? CollectionsKt.emptyList() : list;
    }

    @Override // expo.modules.barcodescanner.scanners.ExpoBarCodeScanner
    public boolean isAvailable() {
        return this.isAvailable;
    }

    @Override // expo.modules.interfaces.barcodescanner.BarCodeScannerInterface
    public BarCodeScannerResult scan(byte[] bArr, int i, int i2, int i3) {
        Intrinsics.checkNotNullParameter(bArr, UriUtil.DATA_SCHEME);
        if (i3 == 0) {
            byte[] bArr2 = new byte[bArr.length];
            int i4 = 0;
            while (i4 < i2) {
                int i5 = i4 + 1;
                int i6 = 0;
                while (i6 < i) {
                    int i7 = i6 + 1;
                    int i8 = (i4 * i) + i6;
                    int i9 = (((i6 * i2) + i2) - i4) - 1;
                    if (i8 >= 0 && i8 < bArr.length && i9 >= 0 && i9 < bArr.length) {
                        bArr2[i9] = bArr[i8];
                    }
                    i6 = i7;
                }
                i4 = i5;
            }
            int i10 = i + i2;
            i2 = i10 - i2;
            i = i10 - i2;
            bArr = bArr2;
        }
        return scan(generateSourceFromImageData(bArr, i, i2));
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x0020 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:20:? A[ADDED_TO_REGION, RETURN, SYNTHETIC] */
    private final BarCodeScannerResult scan(LuminanceSource luminanceSource) {
        Result result;
        BinaryBitmap binaryBitmap;
        Throwable th;
        try {
            binaryBitmap = new BinaryBitmap(new HybridBinarizer(luminanceSource));
            try {
                result = this.mMultiFormatReader.decodeWithState(binaryBitmap);
            } catch (NotFoundException unused) {
            } catch (Throwable th2) {
                th = th2;
                th.printStackTrace();
            }
        } catch (NotFoundException unused2) {
            binaryBitmap = null;
            result = null;
            return binaryBitmap != null ? null : null;
        } catch (Throwable th3) {
            th = th3;
            binaryBitmap = null;
            th.printStackTrace();
            result = null;
            if (binaryBitmap != null) {
            }
        }
        if (binaryBitmap != null && result != null) {
            ArrayList arrayList = new ArrayList();
            Integer num = GMV_FROM_ZXING.get(result.getBarcodeFormat());
            if (num == null) {
                return null;
            }
            return new BarCodeScannerResult(num.intValue(), result.getText(), arrayList, binaryBitmap.getHeight(), binaryBitmap.getWidth());
        }
    }

    @Override // expo.modules.interfaces.barcodescanner.BarCodeScannerInterface
    public void setSettings(BarCodeScannerSettings barCodeScannerSettings) {
        Intrinsics.checkNotNullParameter(barCodeScannerSettings, "settings");
        if (!areNewAndOldBarCodeTypesEqual(parseBarCodeTypesFromSettings(barCodeScannerSettings))) {
            EnumMap enumMap = new EnumMap(DecodeHintType.class);
            EnumSet noneOf = EnumSet.noneOf(BarcodeFormat.class);
            List<Integer> barCodeTypes = getBarCodeTypes();
            if (barCodeTypes != null) {
                Iterator<T> it = barCodeTypes.iterator();
                while (it.hasNext()) {
                    String str = VALID_BARCODE_TYPES.get(Integer.valueOf(it.next().intValue()));
                    if (str != null) {
                        noneOf.add(BarcodeFormat.valueOf(str));
                    }
                }
            }
            EnumMap enumMap2 = enumMap;
            enumMap2.put((Object) DecodeHintType.POSSIBLE_FORMATS, (Object) noneOf);
            this.mMultiFormatReader.setHints(enumMap2);
        }
    }

    private final LuminanceSource generateSourceFromImageData(byte[] bArr, int i, int i2) {
        return new PlanarYUVLuminanceSource(bArr, i, i2, 0, 0, i, i2, false);
    }

    @Metadata(d1 = {"\u0000 \n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0010$\n\u0002\u0018\u0002\n\u0002\u0010\b\n\u0000\n\u0002\u0010\u000e\n\u0000\b\u0003\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002R\u001a\u0010\u0003\u001a\u000e\u0012\u0004\u0012\u00020\u0005\u0012\u0004\u0012\u00020\u00060\u0004X\u0004¢\u0006\u0002\n\u0000R\u001a\u0010\u0007\u001a\u000e\u0012\u0004\u0012\u00020\u0006\u0012\u0004\u0012\u00020\b0\u0004X\u0004¢\u0006\u0002\n\u0000¨\u0006\t"}, d2 = {"Lexpo/modules/barcodescanner/scanners/ZxingBarCodeScanner$Companion;", "", "()V", "GMV_FROM_ZXING", "", "Lcom/google/zxing/BarcodeFormat;", "", "VALID_BARCODE_TYPES", "", "expo-barcode-scanner_release"}, k = 1, mv = {1, 6, 0}, xi = 48)
    /* compiled from: ZxingBarCodeScanner.kt */
    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }
    }
}
