package expo.modules.barcodescanner.utils;

import android.os.Bundle;
import android.util.Pair;
import com.facebook.common.util.UriUtil;
import com.facebook.imagepipeline.producers.ProducerContext;
import expo.modules.interfaces.barcodescanner.BarCodeScannerResult;
import java.util.ArrayList;
import java.util.List;
import kotlin.Metadata;
import kotlin.internal.ProgressionUtilKt;
import kotlin.jvm.internal.Intrinsics;

@Metadata(d1 = {"\u00006\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010 \n\u0002\u0010\b\n\u0000\n\u0002\u0010\u0007\n\u0002\b\b\n\u0002\u0018\u0002\n\u0000\bÆ\u0002\u0018\u00002\u00020\u0001B\u0007\b\u0002¢\u0006\u0002\u0010\u0002J:\u0010\u0003\u001a\u001e\u0012\u0014\u0012\u0012\u0012\u0004\u0012\u00020\u00060\u0005j\b\u0012\u0004\u0012\u00020\u0006`\u0007\u0012\u0004\u0012\u00020\u00060\u00042\f\u0010\b\u001a\b\u0012\u0004\u0012\u00020\n0\t2\u0006\u0010\u000b\u001a\u00020\fH\u0002J\u0018\u0010\r\u001a\u00020\u00062\u0006\u0010\u000e\u001a\u00020\f2\u0006\u0010\u000f\u001a\u00020\fH\u0002J\u0018\u0010\u0010\u001a\u00020\u00062\u0006\u0010\u0011\u001a\u00020\f2\u0006\u0010\u0012\u001a\u00020\fH\u0002J\u0016\u0010\u0013\u001a\u00020\u00062\u0006\u0010\u0014\u001a\u00020\u00152\u0006\u0010\u000b\u001a\u00020\f¨\u0006\u0016"}, d2 = {"Lexpo/modules/barcodescanner/utils/BarCodeScannerResultSerializer;", "", "()V", "getCornerPointsAndBoundingBox", "Landroid/util/Pair;", "Ljava/util/ArrayList;", "Landroid/os/Bundle;", "Lkotlin/collections/ArrayList;", "cornerPoints", "", "", "density", "", "getPoint", "x", "y", "getSize", "width", "height", "toBundle", "result", "Lexpo/modules/interfaces/barcodescanner/BarCodeScannerResult;", "expo-barcode-scanner_release"}, k = 1, mv = {1, 6, 0}, xi = 48)
/* compiled from: BarCodeScannerResultSerializer.kt */
public final class BarCodeScannerResultSerializer {
    public static final BarCodeScannerResultSerializer INSTANCE = new BarCodeScannerResultSerializer();

    private BarCodeScannerResultSerializer() {
    }

    public final Bundle toBundle(BarCodeScannerResult barCodeScannerResult, float f) {
        Intrinsics.checkNotNullParameter(barCodeScannerResult, "result");
        Bundle bundle = new Bundle();
        bundle.putString(UriUtil.DATA_SCHEME, barCodeScannerResult.getValue());
        bundle.putInt("type", barCodeScannerResult.getType());
        List<Integer> cornerPoints = barCodeScannerResult.getCornerPoints();
        Intrinsics.checkNotNullExpressionValue(cornerPoints, "result.cornerPoints");
        if (!cornerPoints.isEmpty()) {
            BarCodeScannerResultSerializer barCodeScannerResultSerializer = INSTANCE;
            List<Integer> cornerPoints2 = barCodeScannerResult.getCornerPoints();
            Intrinsics.checkNotNullExpressionValue(cornerPoints2, "result.cornerPoints");
            Pair<ArrayList<Bundle>, Bundle> cornerPointsAndBoundingBox = barCodeScannerResultSerializer.getCornerPointsAndBoundingBox(cornerPoints2, f);
            bundle.putParcelableArrayList("cornerPoints", (ArrayList) cornerPointsAndBoundingBox.first);
            bundle.putBundle("bounds", (Bundle) cornerPointsAndBoundingBox.second);
        }
        return bundle;
    }

    private final Pair<ArrayList<Bundle>, Bundle> getCornerPointsAndBoundingBox(List<Integer> list, float f) {
        ArrayList arrayList = new ArrayList();
        int i = 0;
        int progressionLastElement = ProgressionUtilKt.getProgressionLastElement(0, list.size() - 1, 2);
        float f2 = Float.MIN_VALUE;
        float f3 = Float.MIN_VALUE;
        float f4 = Float.MAX_VALUE;
        float f5 = Float.MAX_VALUE;
        if (progressionLastElement >= 0) {
            while (true) {
                int i2 = i + 2;
                float intValue = ((float) list.get(i).intValue()) / f;
                float intValue2 = ((float) list.get(i + 1).intValue()) / f;
                f4 = Math.min(f4, intValue);
                f5 = Math.min(f5, intValue2);
                f2 = Math.max(f2, intValue);
                f3 = Math.max(f3, intValue2);
                arrayList.add(getPoint(intValue, intValue2));
                if (i == progressionLastElement) {
                    break;
                }
                i = i2;
            }
        }
        Bundle bundle = new Bundle();
        BarCodeScannerResultSerializer barCodeScannerResultSerializer = INSTANCE;
        bundle.putParcelable(ProducerContext.ExtraKeys.ORIGIN, barCodeScannerResultSerializer.getPoint(f4, f5));
        bundle.putParcelable("size", barCodeScannerResultSerializer.getSize(f2 - f4, f3 - f5));
        return new Pair<>(arrayList, bundle);
    }

    private final Bundle getSize(float f, float f2) {
        Bundle bundle = new Bundle();
        bundle.putFloat("width", f);
        bundle.putFloat("height", f2);
        return bundle;
    }

    private final Bundle getPoint(float f, float f2) {
        Bundle bundle = new Bundle();
        bundle.putFloat("x", f);
        bundle.putFloat("y", f2);
        return bundle;
    }
}
