package expo.modules.clipboard;

import android.content.ClipData;
import android.content.ClipDescription;
import android.content.Context;
import android.os.Build;
import android.text.Html;
import android.text.Spanned;
import android.text.TextUtils;
import androidx.webkit.internal.AssetHelper;
import kotlin.jvm.internal.Intrinsics;

public final class ClipboardModuleKt {
    public static final String CLIPBOARD_CHANGED_EVENT_NAME;
    public static final String CLIPBOARD_DIRECTORY_NAME;
    private static final String TAG = "ClipboardModule";
    private static final String moduleName;

    public static final String plainTextFromHtml(String str) {
        Spanned spanned;
        if (Build.VERSION.SDK_INT >= 24) {
            spanned = Html.fromHtml(str, 0);
            Intrinsics.checkNotNullExpressionValue(spanned, "{\n    Html.fromHtml(html…ROM_HTML_MODE_LEGACY)\n  }");
        } else {
            spanned = Html.fromHtml(str);
            Intrinsics.checkNotNullExpressionValue(spanned, "{\n    @Suppress(\"DEPRECA…fromHtml(htmlContent)\n  }");
        }
        char[] cArr = new char[spanned.length()];
        TextUtils.getChars(spanned, 0, spanned.length(), cArr, 0);
        return new String(cArr);
    }

    public static final String coerceToPlainText(ClipData.Item item, Context context) {
        if (item.getText() != null || item.getHtmlText() == null) {
            return item.coerceToText(context).toString();
        }
        String htmlText = item.getHtmlText();
        Intrinsics.checkNotNullExpressionValue(htmlText, "htmlText");
        return plainTextFromHtml(htmlText);
    }

    public static final boolean getHasTextContent(ClipDescription clipDescription) {
        return clipDescription.hasMimeType(AssetHelper.DEFAULT_MIME_TYPE) || clipDescription.hasMimeType("text/html");
    }
}
