package expo.modules.localization;

import android.text.TextUtils;
import java.util.ArrayList;
import java.util.Currency;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Objects;
import kotlin.Lazy;
import kotlin.LazyKt;
import kotlin.Metadata;
import kotlin.Result;
import kotlin.ResultKt;
import kotlin.collections.CollectionsKt;
import kotlin.jvm.internal.Intrinsics;

@Metadata(d1 = {"\u0000\u001e\n\u0000\n\u0002\u0010\u0011\n\u0002\u0010\u000e\n\u0002\b\u0005\n\u0002\u0010 \n\u0002\b\u0004\n\u0002\u0018\u0002\n\u0002\b\b\u001a\u0010\u0010\u000b\u001a\u0004\u0018\u00010\u00022\u0006\u0010\f\u001a\u00020\r\u001a\u0010\u0010\u000e\u001a\u0004\u0018\u00010\u00022\u0006\u0010\f\u001a\u00020\r\u001a'\u0010\u000f\u001a\u0010\u0012\f\u0012\n \u0010*\u0004\u0018\u00010\u00020\u00020\u00012\f\u0010\u0011\u001a\b\u0012\u0004\u0012\u00020\r0\b¢\u0006\u0002\u0010\u0012\u001a\u000e\u0010\u0013\u001a\u00020\u00022\u0006\u0010\u0014\u001a\u00020\u0002\"!\u0010\u0000\u001a\b\u0012\u0004\u0012\u00020\u00020\u00018FX\u0002¢\u0006\f\n\u0004\b\u0005\u0010\u0006\u001a\u0004\b\u0003\u0010\u0004\"\u0017\u0010\u0007\u001a\b\u0012\u0004\u0012\u00020\u00020\b¢\u0006\b\n\u0000\u001a\u0004\b\t\u0010\n¨\u0006\u0015"}, d2 = {"ISOCurrencyCodes", "", "", "getISOCurrencyCodes", "()[Ljava/lang/String;", "ISOCurrencyCodes$delegate", "Lkotlin/Lazy;", "USES_IMPERIAL", "", "getUSES_IMPERIAL", "()Ljava/util/List;", "getCountryCode", "locale", "Ljava/util/Locale;", "getCurrencyCode", "getLocaleNames", "kotlin.jvm.PlatformType", "locales", "(Ljava/util/List;)[Ljava/lang/String;", "getSystemProperty", "key", "expo-localization_release"}, k = 2, mv = {1, 6, 0}, xi = 48)
/* compiled from: LocalizationUtils.kt */
public final class LocalizationUtilsKt {
    private static final Lazy ISOCurrencyCodes$delegate = LazyKt.lazy(LocalizationUtilsKt$ISOCurrencyCodes$2.INSTANCE);
    private static final List<String> USES_IMPERIAL = CollectionsKt.listOf((Object[]) new String[]{"US", "LR", "MM"});

    public static final List<String> getUSES_IMPERIAL() {
        return USES_IMPERIAL;
    }

    public static final String[] getISOCurrencyCodes() {
        return (String[]) ISOCurrencyCodes$delegate.getValue();
    }

    public static final String[] getLocaleNames(List<Locale> list) {
        Intrinsics.checkNotNullParameter(list, "locales");
        List<Locale> list2 = list;
        ArrayList arrayList = new ArrayList(CollectionsKt.collectionSizeOrDefault(list2, 10));
        Iterator<T> it = list2.iterator();
        while (it.hasNext()) {
            arrayList.add(it.next().toLanguageTag());
        }
        Object[] array = arrayList.toArray(new String[0]);
        Objects.requireNonNull(array, "null cannot be cast to non-null type kotlin.Array<T of kotlin.collections.ArraysKt__ArraysJVMKt.toTypedArray>");
        return (String[]) array;
    }

    public static final String getCountryCode(Locale locale) {
        Object obj;
        Intrinsics.checkNotNullParameter(locale, "locale");
        String str = null;
        try {
            Result.Companion companion = Result.Companion;
            String country = locale.getCountry();
            if (TextUtils.isEmpty(country)) {
                country = null;
            }
            obj = Result.m126constructorimpl(country);
        } catch (Throwable th) {
            Result.Companion companion2 = Result.Companion;
            obj = Result.m126constructorimpl(ResultKt.createFailure(th));
        }
        if (!Result.m132isFailureimpl(obj)) {
            str = obj;
        }
        return str;
    }

    public static final String getSystemProperty(String str) {
        Object obj;
        Intrinsics.checkNotNullParameter(str, "key");
        try {
            Result.Companion companion = Result.Companion;
            Class<?> cls = Class.forName("android.os.SystemProperties");
            Object invoke = cls.getMethod("get", String.class).invoke(cls, str);
            if (invoke != null) {
                obj = Result.m126constructorimpl((String) invoke);
                if (Result.m132isFailureimpl(obj)) {
                    obj = null;
                }
                String str2 = (String) obj;
                return str2 == null ? "" : str2;
            }
            throw new NullPointerException("null cannot be cast to non-null type kotlin.String");
        } catch (Throwable th) {
            Result.Companion companion2 = Result.Companion;
            obj = Result.m126constructorimpl(ResultKt.createFailure(th));
        }
    }

    public static final String getCurrencyCode(Locale locale) {
        Object obj;
        String str;
        Intrinsics.checkNotNullParameter(locale, "locale");
        String str2 = null;
        try {
            Result.Companion companion = Result.Companion;
            Currency instance = Currency.getInstance(locale);
            if (instance == null) {
                str = null;
            } else {
                str = instance.getCurrencyCode();
            }
            obj = Result.m126constructorimpl(str);
        } catch (Throwable th) {
            Result.Companion companion2 = Result.Companion;
            obj = Result.m126constructorimpl(ResultKt.createFailure(th));
        }
        if (!Result.m132isFailureimpl(obj)) {
            str2 = obj;
        }
        return str2;
    }
}
