package com.facebook.react.uimanager.events;

import android.view.MotionEvent;
import androidx.core.util.Pools;
import com.facebook.infer.annotation.Assertions;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactSoftExceptionLogger;
import com.facebook.react.bridge.WritableMap;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class PointerEvent extends Event<PointerEvent> {
    private static final Pools.SynchronizedPool<PointerEvent> EVENTS_POOL = new Pools.SynchronizedPool<>(6);
    private static final int POINTER_EVENTS_POOL_SIZE = 6;
    private static final String TAG = "PointerEvent";
    private static final int UNSET_COALESCING_KEY = -1;
    private int mCoalescingKey = -1;
    private String mEventName;
    private MotionEvent mMotionEvent;

    @Override // com.facebook.react.uimanager.events.Event
    public void dispatch(RCTEventEmitter rCTEventEmitter) {
    }

    public static PointerEvent obtain(String str, int i, int i2, MotionEvent motionEvent) {
        PointerEvent acquire = EVENTS_POOL.acquire();
        if (acquire == null) {
            acquire = new PointerEvent();
        }
        acquire.init(str, i, i2, (MotionEvent) Assertions.assertNotNull(motionEvent), 0);
        return acquire;
    }

    public static PointerEvent obtain(String str, int i, int i2, MotionEvent motionEvent, int i3) {
        PointerEvent acquire = EVENTS_POOL.acquire();
        if (acquire == null) {
            acquire = new PointerEvent();
        }
        acquire.init(str, i, i2, (MotionEvent) Assertions.assertNotNull(motionEvent), i3);
        return acquire;
    }

    private void init(String str, int i, int i2, MotionEvent motionEvent, int i3) {
        super.init(i, i2, motionEvent.getEventTime());
        this.mEventName = str;
        this.mMotionEvent = MotionEvent.obtain(motionEvent);
        this.mCoalescingKey = i3;
    }

    private PointerEvent() {
    }

    @Override // com.facebook.react.uimanager.events.Event
    public String getEventName() {
        return this.mEventName;
    }

    @Override // com.facebook.react.uimanager.events.Event
    public void onDispose() {
        MotionEvent motionEvent = this.mMotionEvent;
        this.mMotionEvent = null;
        if (motionEvent != null) {
            motionEvent.recycle();
        }
        try {
            EVENTS_POOL.release(this);
        } catch (IllegalStateException e) {
            ReactSoftExceptionLogger.logSoftException(TAG, e);
        }
    }

    private ArrayList<WritableMap> createPointerEvents() {
        MotionEvent motionEvent = this.mMotionEvent;
        ArrayList<WritableMap> arrayList = new ArrayList<>();
        for (int i = 0; i < motionEvent.getPointerCount(); i++) {
            arrayList.add(createPointerEvent(i));
        }
        return arrayList;
    }

    private WritableMap createPointerEvent(int i) {
        WritableMap createMap = Arguments.createMap();
        createMap.putDouble("pointerId", (double) this.mMotionEvent.getPointerId(i));
        createMap.putDouble("pressure", (double) this.mMotionEvent.getPressure(i));
        createMap.putString("pointerType", PointerEventHelper.getW3CPointerType(this.mMotionEvent.getToolType(i)));
        createMap.putDouble("clientX", (double) this.mMotionEvent.getX(i));
        createMap.putDouble("clientY", (double) this.mMotionEvent.getY(i));
        createMap.putInt(TouchesHelper.TARGET_KEY, getViewTag());
        createMap.putDouble("timestamp", (double) getTimestampMs());
        return createMap;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    @Override // com.facebook.react.uimanager.events.Event
    public void dispatchModern(RCTModernEventEmitter rCTModernEventEmitter) {
        char c;
        MotionEvent motionEvent = this.mMotionEvent;
        if (motionEvent == null) {
            ReactSoftExceptionLogger.logSoftException(TAG, new IllegalStateException("Cannot dispatch a Pointer that has no MotionEvent; the PointerEvehas been recycled"));
            return;
        }
        List<WritableMap> list = null;
        int actionIndex = motionEvent.getActionIndex();
        String str = this.mEventName;
        str.hashCode();
        switch (str.hashCode()) {
            case -1779094471:
                if (str.equals(PointerEventHelper.POINTER_MOVE)) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case -1304584214:
                if (str.equals(PointerEventHelper.POINTER_DOWN)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case -1065042973:
                if (str.equals(PointerEventHelper.POINTER_UP)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case 383186882:
                if (str.equals(PointerEventHelper.POINTER_CANCEL)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case 452631970:
                if (str.equals(PointerEventHelper.POINTER_ENTER)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case 644174243:
                if (str.equals(PointerEventHelper.POINTER_LEAVE)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
            case 3:
                list = createPointerEvents();
                break;
            case 1:
            case 2:
            case 4:
            case 5:
                list = Arrays.asList(createPointerEvent(actionIndex));
                break;
        }
        if (list != null) {
            boolean z = list.size() > 1;
            for (WritableMap writableMap : list) {
                if (z) {
                    writableMap = writableMap.copy();
                }
                int surfaceId = getSurfaceId();
                int viewTag = getViewTag();
                String str2 = this.mEventName;
                int i = this.mCoalescingKey;
                rCTModernEventEmitter.receiveEvent(surfaceId, viewTag, str2, i != -1, i, writableMap, PointerEventHelper.getEventCategory(str2));
            }
        }
    }
}
