package expo.modules.splashscreen;

import android.app.Activity;
import android.os.Handler;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import expo.modules.splashscreen.exceptions.NoContentViewException;
import java.lang.ref.WeakReference;
import kotlin.Unit;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.Intrinsics;

public class SplashScreenViewController {
    private boolean autoHideEnabled;
    private final ViewGroup contentView;
    private final Handler handler;
    private ViewGroup rootView;
    private final Class<? extends ViewGroup> rootViewClass;
    private boolean splashScreenShown;
    private final View splashScreenView;
    private final WeakReference<Activity> weakActivity;

    public SplashScreenViewController(Activity activity, Class<? extends ViewGroup> cls, View view) {
        Intrinsics.checkNotNullParameter(activity, "activity");
        Intrinsics.checkNotNullParameter(cls, "rootViewClass");
        Intrinsics.checkNotNullParameter(view, "splashScreenView");
        this.rootViewClass = cls;
        this.splashScreenView = view;
        this.weakActivity = new WeakReference<>(activity);
        ViewGroup viewGroup = (ViewGroup) activity.findViewById(16908290);
        if (viewGroup != null) {
            this.contentView = viewGroup;
            this.handler = new Handler();
            this.autoHideEnabled = true;
            return;
        }
        throw new NoContentViewException();
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: expo.modules.splashscreen.SplashScreenViewController */
    /* JADX WARN: Multi-variable type inference failed */
    public static /* synthetic */ void showSplashScreen$default(SplashScreenViewController splashScreenViewController, Function0 function0, int i, Object obj) {
        if (obj == null) {
            if ((i & 1) != 0) {
                function0 = SplashScreenViewController$showSplashScreen$1.INSTANCE;
            }
            splashScreenViewController.showSplashScreen(function0);
            return;
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: showSplashScreen");
    }

    public void showSplashScreen(Function0<Unit> function0) {
        Intrinsics.checkNotNullParameter(function0, "successCallback");
        Activity activity = this.weakActivity.get();
        if (activity != null) {
            activity.runOnUiThread(new SplashScreenViewController$$ExternalSyntheticLambda1(this, function0));
        }
    }

    /* renamed from: showSplashScreen$lambda-0 */
    public static final void m117showSplashScreen$lambda0(SplashScreenViewController splashScreenViewController, Function0 function0) {
        Intrinsics.checkNotNullParameter(splashScreenViewController, "this$0");
        Intrinsics.checkNotNullParameter(function0, "$successCallback");
        ViewParent parent = splashScreenViewController.splashScreenView.getParent();
        ViewGroup viewGroup = parent instanceof ViewGroup ? (ViewGroup) parent : null;
        if (viewGroup != null) {
            viewGroup.removeView(splashScreenViewController.splashScreenView);
        }
        splashScreenViewController.contentView.addView(splashScreenViewController.splashScreenView);
        splashScreenViewController.splashScreenShown = true;
        function0.invoke();
        splashScreenViewController.searchForRootView();
    }

    public final void preventAutoHide(Function1<? super Boolean, Unit> function1, Function1<? super String, Unit> function12) {
        Intrinsics.checkNotNullParameter(function1, "successCallback");
        Intrinsics.checkNotNullParameter(function12, "failureCallback");
        if (!this.autoHideEnabled || !this.splashScreenShown) {
            function1.invoke(false);
            return;
        }
        this.autoHideEnabled = false;
        function1.invoke(true);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: expo.modules.splashscreen.SplashScreenViewController */
    /* JADX WARN: Multi-variable type inference failed */
    public static /* synthetic */ void hideSplashScreen$default(SplashScreenViewController splashScreenViewController, Function1 function1, Function1 function12, int i, Object obj) {
        if (obj == null) {
            if ((i & 1) != 0) {
                function1 = SplashScreenViewController$hideSplashScreen$1.INSTANCE;
            }
            if ((i & 2) != 0) {
                function12 = SplashScreenViewController$hideSplashScreen$2.INSTANCE;
            }
            splashScreenViewController.hideSplashScreen(function1, function12);
            return;
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: hideSplashScreen");
    }

    public void hideSplashScreen(Function1<? super Boolean, Unit> function1, Function1<? super String, Unit> function12) {
        Intrinsics.checkNotNullParameter(function1, "successCallback");
        Intrinsics.checkNotNullParameter(function12, "failureCallback");
        if (!this.splashScreenShown) {
            function1.invoke(false);
            return;
        }
        Activity activity = this.weakActivity.get();
        if (activity == null || activity.isFinishing() || activity.isDestroyed()) {
            function12.invoke("Cannot hide native splash screen on activity that is already destroyed (application is already closed).");
        } else {
            activity.runOnUiThread(new SplashScreenViewController$$ExternalSyntheticLambda2(this, function1));
        }
    }

    /* renamed from: hideSplashScreen$lambda-1 */
    public static final void m115hideSplashScreen$lambda1(SplashScreenViewController splashScreenViewController, Function1 function1) {
        Intrinsics.checkNotNullParameter(splashScreenViewController, "this$0");
        Intrinsics.checkNotNullParameter(function1, "$successCallback");
        splashScreenViewController.contentView.removeView(splashScreenViewController.splashScreenView);
        splashScreenViewController.autoHideEnabled = true;
        splashScreenViewController.splashScreenShown = false;
        function1.invoke(true);
    }

    private final void searchForRootView() {
        if (this.rootView == null) {
            ViewGroup findRootView = findRootView(this.contentView);
            if (findRootView == null) {
                this.handler.postDelayed(new SplashScreenViewController$$ExternalSyntheticLambda0(this), 20);
            } else {
                handleRootView(findRootView);
            }
        }
    }

    /* renamed from: searchForRootView$lambda-3 */
    public static final void m116searchForRootView$lambda3(SplashScreenViewController splashScreenViewController) {
        Intrinsics.checkNotNullParameter(splashScreenViewController, "this$0");
        splashScreenViewController.searchForRootView();
    }

    private final ViewGroup findRootView(View view) {
        if (this.rootViewClass.isInstance(view)) {
            return (ViewGroup) view;
        }
        if (Intrinsics.areEqual(view, this.splashScreenView) || !(view instanceof ViewGroup)) {
            return null;
        }
        int i = 0;
        ViewGroup viewGroup = (ViewGroup) view;
        int childCount = viewGroup.getChildCount();
        while (i < childCount) {
            int i2 = i + 1;
            View childAt = viewGroup.getChildAt(i);
            Intrinsics.checkNotNullExpressionValue(childAt, "view.getChildAt(idx)");
            ViewGroup findRootView = findRootView(childAt);
            if (findRootView != null) {
                return findRootView;
            }
            i = i2;
        }
        return null;
    }

    private final void handleRootView(ViewGroup viewGroup) {
        int i;
        this.rootView = viewGroup;
        if (viewGroup == null) {
            i = 0;
        } else {
            i = viewGroup.getChildCount();
        }
        if (i > 0 && this.autoHideEnabled) {
            hideSplashScreen$default(this, null, null, 3, null);
        }
        viewGroup.setOnHierarchyChangeListener(new SplashScreenViewController$handleRootView$1(this));
    }
}
