package expo.modules.systemui;

import android.app.Activity;
import android.content.Context;
import android.graphics.Color;
import com.facebook.react.bridge.BaseJavaModule;
import expo.modules.core.ExportedModule;
import expo.modules.core.ModuleRegistry;
import expo.modules.core.Promise;
import expo.modules.core.errors.CurrentActivityNotFoundException;
import expo.modules.core.interfaces.ActivityProvider;
import java.util.Arrays;
import kotlin.Unit;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.StringCompanionObject;

public final class SystemUIModule extends ExportedModule {
    public static final Companion Companion = new Companion(null);
    private static final String ERROR_TAG;
    private static final String NAME;
    private ActivityProvider activityProvider;

    @Override // expo.modules.core.ExportedModule
    public String getName() {
        return NAME;
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public SystemUIModule(Context context) {
        super(context);
        Intrinsics.checkNotNullParameter(context, "context");
    }

    @Override // expo.modules.core.interfaces.RegistryLifecycleListener, expo.modules.core.ExportedModule
    public void onCreate(ModuleRegistry moduleRegistry) {
        Intrinsics.checkNotNullParameter(moduleRegistry, "moduleRegistry");
        ActivityProvider activityProvider2 = (ActivityProvider) moduleRegistry.getModule(ActivityProvider.class);
        if (activityProvider2 != null) {
            this.activityProvider = activityProvider2;
            return;
        }
        throw new IllegalStateException("Could not find implementation for ActivityProvider.");
    }

    private final void safeRunOnUiThread(Promise promise, Function1<? super Activity, Unit> function1) {
        ActivityProvider activityProvider2 = this.activityProvider;
        if (activityProvider2 == null) {
            Intrinsics.throwUninitializedPropertyAccessException("activityProvider");
            activityProvider2 = null;
        }
        Activity currentActivity = activityProvider2.getCurrentActivity();
        if (currentActivity == null) {
            promise.reject(new CurrentActivityNotFoundException());
        } else {
            currentActivity.runOnUiThread(new SystemUIModule$$ExternalSyntheticLambda0(function1, currentActivity));
        }
    }

    /* renamed from: safeRunOnUiThread$lambda-0 */
    public static final void m121safeRunOnUiThread$lambda0(Function1 function1, Activity activity) {
        Intrinsics.checkNotNullParameter(function1, "$block");
        Intrinsics.checkNotNullExpressionValue(activity, "activity");
        function1.invoke(activity);
    }

    public final void setBackgroundColorAsync(int i, Promise promise) {
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        safeRunOnUiThread(promise, new SystemUIModule$setBackgroundColorAsync$1(i, promise));
    }

    public final void getBackgroundColorAsync(Promise promise) {
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        safeRunOnUiThread(promise, new SystemUIModule$getBackgroundColorAsync$1(promise));
    }

    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }

        public final String colorToHex(int i) {
            StringCompanionObject stringCompanionObject = StringCompanionObject.INSTANCE;
            String format = String.format("#%02x%02x%02x", Arrays.copyOf(new Object[]{Integer.valueOf(Color.red(i)), Integer.valueOf(Color.green(i)), Integer.valueOf(Color.blue(i))}, 3));
            Intrinsics.checkNotNullExpressionValue(format, "format(format, *args)");
            return format;
        }
    }
}
